@@ -64,7 +64,7 @@ function(formLatticeOutput,Z,PointPattern,M=0.5,max_steps = 200){
 #
 #                                                             
 #
-  if(class(formLatticeOutput)!="formLatticeOutput"){
+  if(!inherits(formLatticeOutput,"formLatticeOutput")){
        stop("Should be the output from the function formLattice")}
   if((M==0)|(M==1)){
              warning("Setting M to zero or one is ill-advised")}
